#!/usr/bin/bash
#---------------------------------------------------------------------
# MODE D'EMPLOI :
# Ce script est pensé pour être exécuté depuis le dossier PROJET de notre environnement de travail et de projet.
# Notre commande pour le lancer contient deux argeuments: 
# Il faut indiquer quel est le dossier où ont été enregistré nos URLS, sans oublier de spécifier l'emplacement du fichier html que l'on générera
# Voici la commande: 
# bash ./PROGRAMMES/projet-script-fin.sh ./URLS ./TABLEAUX/tableau.html " french|kiss|fransız|öpücüğü|fransiz|opucugu"
#---------------------------------------------------------------------
# On choisi des variables pour stocker les arguments que l'on vient de spécifier:
dossierURL=$1;
tableaux=$2;
motif=$3; #On ajoute une variable qui contendrait le nombre d'ocurrences du mot chosi 
#-----------------------------------------------------------------------
# Création du fichier HTML en indiquant le jeu de caractères utilisé et le style:   
echo "<html><head><meta charset=\"utf-8\" /><style>
body {
font-family:monospace;
}
h1 {
font-size:26;
color:#6495ed;
}
h2 {
font-size:24;
color:#6495ed;
}
h3 {
font-size:22;
color:#6495ed;
}
table {
border:3px solid #6495ed;
border-collapse:collapse;
width:90%;
margin:auto;
}
thead, tfoot {
background-color:#D0E3FA;
border:1px solid #6495ed;
}
tbody {
background-color:#FFFFFF;
border:1px solid #6495ed;
}
th {
font-family:monospace;
border:1px dotted #6495ed;
padding:5px;
background-color:#EFF6FF;
text-align: center;
}
td {
font-family:monospace;
font-size:90%;
border:1px solid #6495ed;
padding:5px;
text-align:left;
text-align: center;
}
caption {
font-family:sans-serif;
}
</style></head><body>" > $tableaux ;
# Un compteur pour chaque fichier URL et donc pour chaque tableau associé à celui-ci 
compteur_tableau=1;
# On parcourt le dossier afin de individualiser chaque fichier d'URL en utlisant la commande ls sur notre variable
for fichier in $(ls $dossierURL)
	do
		# Pour chaque fichier d'URLs, on va créer un nouveau tableau qui contendrait 7 colonnes
		echo $fichier;
		echo "<table align=\"center\" border=\"10px\" bordercolor=\"red\">" >> $tableaux;
		compteur=1; # compteur d'URL qui servira à les énumérer et à nommer les pages aspirées   
		echo "<tr><th colspan=\"11\">TABLEAU $compteur_tableau</th></tr>" >> $tableaux;
		echo "<tr><th colspan=\"11\">MOTIF : $motif</th></tr>" >> $tableaux;
		echo "<tr><td>CPT</td>
		<td>HTTP</td>
		<td>Encodage</td>
		<td>URL</td>
		<td>P.A</td>
		<td>DUMP</td>
		<td>CPT MOTIF</td>
		<td>Contextes txt</td>
		<td>Contextes html</td>
		<td>Index</td>
		<td>Bigrammes</td></tr>" >> $tableaux;
		# ensuite on parcourt chaque ligne, c'est-à-dire chaque URL, afin de remplir le tableau jusqu'à ce que l'on trouve plus 
		while read ligne
		do
		# chaque URL est traitée et ajoutée au tableau 
		echo "-----------------------------------------------------------";
		echo "TRAITEMENT DE URL : $ligne";
		# on recupére le code http dans une variable avec le but de savoir si la conection s'est bien passée 
		# pour cela, on utilise la commande curl qui, d'une seule fois, recupérer le code http et aspire les pages 
		codehttp=$(curl -s -L -o ./PAGES-ASPIREES/"$compteur_tableau-$compteur".html $ligne  -w %{http_code}) ; 
		# --------------------------------------------------------------------
		if [[ $codehttp == 200 ]]
		# si la valeur de la variable codehttp est 200, on extrait aussi l'encodage utilisé à travers la commande egrep, cut et tr pour aficher le code en majuscules et eliminer \r
		then
			encodageURL=$(curl -I $ligne | egrep -i "charset" | cut -f2 -d= | tr [a-z] [A-Z] | tr -d "\r");
			echo "<$encodageURL>";
			# on verifie si l'encodage est UTF-8, si il l'est on continue avec le traitement 
			if [[ $encodageURL == "UTF-8" ]]
			then
				echo "HTTP OK UTF8----------------------------------"
				echo "<$compteur_tableau><$compteur><$ligne><$codehttp><$encodageURL>";
				#---------------------------------------------------------
				# 1er traitement : étant UTF-8, on récupère le text brut de chaque page aspirée à travers la commande lynx, en situant le résultat dans le répertoire DUMP-TEXT
				lynx -dump -nolist -assume_charset="UTF-8" -display_charset="UTF-8" ./PAGES-ASPIREES/"$compteur_tableau-$compteur".html > ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt;
				#---------------------------------------------------------
				# 2eme traitement : on compte les occurrences du mot choisi avec egrep et wc 
				compteurMotif=$(egrep -o -i $motif ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | wc -l);
				#---------------------------------------------------------
				# 3ème traitement, a) : nous allons extraire des contextes textuels de notre motif plus larges.
				egrep -C 2 -i "$motif" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt > ./CONTEXTES/utf8_"$compteur_tableau-$compteur".txt;
				# 3 b) : avec le programme mini-egrep, nous creons un fichier html pour meiux afficher nos contextes. On deplacera le résultat au dossier CONTEXTES. 
				perl ./PROGRAMMES/minigrepmultilingue-v2.2-regexp/minigrepmultilingue.pl "UTF-8" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt ./PROGRAMMES/minigrepmultilingue-v2.2-regexp/motif-regexp.txt
				mv resultat-extraction.html ./CONTEXTES/"$compteur_tableau-$compteur".html
				#---------------------------------------------------------
				
				# 4ème traitement : Nous ferons un index ordonné de manière hierarchiques à partir du fichiers DUMP
				egrep -i -o "\w+" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | sort | uniq -c  | sort -r -n -s -k 1,1 > ./DUMP-TEXT/index_"$compteur_tableau-$compteur".txt ;
				# 5ème traitement : Ensuite, on calcule les bigrammes pour connaître le contexte immédiat de notre motif.
				tr " " "\n" < ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | tr -s "\n" | egrep -v "^$" > index1.txt ; tail -n +2 index1.txt  > index2.txt; paste index1.txt index2.txt | sort | uniq -c | sort -r -n -s -k 1,1 -r > ./DUMP-TEXT/bigramme_"$compteur_tableau-$compteur".txt ;
				#---------------------------------------------------------
				# si le code http est 200 et l'encodage UTF-8, on remplit les colonnes avec les donées récoltées à partir de traitements juste expliqués. Le couleur jaune indique le bon traitement. 
				echo "<tr><td>$compteur</td>
				<td><span style=\"background-color:yellow\">$codehttp</span></td>
				<td><span style=\"background-color:yellow\">$encodageURL</span><br/><small>(cURL)</small></td>
				<td><a target=\"_blank\" href=\"$ligne\">$ligne</a></td>
				<td><a href=\"../PAGES-ASPIREES/$compteur_tableau-$compteur.html\">P.A n&deg;$compteur</a></td>
				<td><a href=\"../DUMP-TEXT/utf8_$compteur_tableau-$compteur.txt\">DUMP n&deg;$compteur</a></td><td>$compteurMotif</td>
				<td><a href=\"../CONTEXTES/utf8_$compteur_tableau-$compteur.txt\">contexte $compteur</a></td>
				<td><a href=\"../CONTEXTES/$compteur_tableau-$compteur.html\">contexte $compteur</a></td>
				<td><a href=\"../DUMP-TEXT/index_$compteur_tableau-$compteur.txt\">index $compteur</a></td>
				<td><a href=\"../DUMP-TEXT/bigramme_$compteur_tableau-$compteur.txt\">bigramme $compteur</a></td>
				<tr>" >> $tableaux;
				#-----------------------#
			else
				# Si l'encodage n'est pas UTF-8 mais le code HTTP est correct
				echo "HTTP OK, NOT UTF8----------------------------------"
				echo "<$compteur_tableau><$compteur><$ligne><$codehttp><$encodageURL>";
				if [[ $encodageURL != "" ]]
				then
					reponse=$(iconv -l | egrep "$encodageURL");
					if [[ $reponse !=  "" ]]
					then
						#---------------------------------------------------------
						# 1er traitement : étant UTF-8, on récupère le text brut de chaque page aspirée à travers la commande lynx, en situant le résultat dans le répertoire DUMP-TEXT
						lynx -dump -nolist -assume_charset="UTF-8" -display_charset="UTF-8" ./PAGES-ASPIREES/"$compteur_tableau-$compteur".html > ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt;
						#---------------------------------------------------------
						iconv -t "$encodageURL" -f "UTF-8" < ./DUMP-TEXT/"$compteur_tableau-$compteur".html > ./DUMP-TEXT/"$compteur_tableau-$compteur".html
						# 2eme traitement : on compte les occurrences du mot choisi avec egrep et wc 
						compteurMotif=$(egrep -o -i $motif ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | wc -l);
						#---------------------------------------------------------
						# 3ème traitement, a) : nous allons extraire des contextes textuels de notre motif plus larges.
						egrep -C 2 -i "$motif" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt > ./CONTEXTES/utf8_"$compteur_tableau-$compteur".txt;
						# 3 b) : avec le programme mini-egrep, nous creons un fichier html pour meiux afficher nos contextes. On deplacera le résultat au dossier CONTEXTES. 
						perl ./PROGRAMMES/minigrepmultilingue-v2.2-regexp/minigrepmultilingue.pl "UTF-8" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt ./PROGRAMMES/minigrepmultilingue-v2.2-regexp/motif-regexp.txt
						mv resultat-extraction.html ./CONTEXTES/"$compteur_tableau-$compteur".html
						#---------------------------------------------------------
						
						# 4ème traitement : Nous ferons un index ordonné de manière hierarchiques à partir du fichiers DUMP
						egrep -i -o "\w+" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | sort | uniq -c  | sort -r -n -s -k 1,1 > ./DUMP-TEXT/index_"$compteur_tableau-$compteur".txt ;
						# 5ème traitement : Ensuite, on calcule les bigrammes pour connaître le contexte immédiat de notre motif.
						tr " " "\n" < ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | tr -s "\n" | egrep -v "^$" > index1.txt ; tail -n +2 index1.txt  > index2.txt; paste index1.txt index2.txt | sort | uniq -c | sort -r -n -s -k 1,1 -r > ./DUMP-TEXT/bigramme_"$compteur_tableau-$compteur".txt ;
						#---------------------------------------------------------
						echo "<tr><td>$compteur</td>
						<td><span style=\"background-color:#00FF80\">$codehttp</span></td>
						<td><span style=\"background-color:#00FF80\">$encodageURL</span><br/><small>(cURL)</small></td>
						<td><a target=\"_blank\" href=\"$ligne\">$ligne</a></td>
						<td><a href=\"../PAGES-ASPIREES/$compteur_tableau-$compteur.html\">P.A n&deg;$compteur</a></td>
						<td><a href=\"../DUMP-TEXT/utf8_$compteur_tableau-$compteur.txt\">DUMP n&deg;$compteur</a></td><td>$compteurMotif</td>
						<td><a href=\"../CONTEXTES/utf8_$compteur_tableau-$compteur.txt\">contexte $compteur</a></td>
						<td><a href=\"../CONTEXTES/$compteur_tableau-$compteur.html\">contexte $compteur</a></td>
						<td><a href=\"../DUMP-TEXT/index_$compteur_tableau-$compteur.txt\">index $compteur</a></td>
						<td><a href=\"../DUMP-TEXT/bigramme_$compteur_tableau-$compteur.txt\">bigramme $compteur</a></td>
						<tr>" >> $tableaux;
					else
						# On remplit les colonnes en orange et on indique les donées qui ne sont pas encore extraites avec deux signes d'interrogation 
						echo "<tr><td>$compteur</td>
						<td><span style=\"background-color:#f97b5c\">$codehttp</span></td>
						<td><span style=\"background-color:#f97b5c\">$encodageURL</span></td>
						<td><a target=\"_blank\" href=\"$ligne\">$ligne</a></td>
						<td><a href=\"../PAGES-ASPIREES/$compteur_tableau-$compteur.html\">P.A n&deg;$compteur</a></td>
						<td><span style=\"background-color:#f97b5c\">??</span></td>
						<td><span style=\"background-color:#f97b5c\">??</span></td><tr>" >> $tableaux;
					fi
				else
					encodageExtrait=$(perl ./PROGRAMMES/detect-encoding.pl ./PAGES-ASPIREES/"$compteur_tableau-$compteur".html | tr -d "\n" | tr -d "\r")
					echo "ENCODAGE EXTRAIT : $encodageExtrait";
					reponse=$(iconv -l |egrep "\b$encodageURL\b");
					reponse=$(iconv -l |egrep "\b$encodageExtrait\b");
					if [[ $reponse !=  "" ]]
					then
						#---------------------------------------------------------
						# 1. récupèration du text brut de chaque page aspirée à travers la commande lynx, en situant le résultat dans DUMP-TEXT
						lynx -dump -nolist -assume_charset="UTF-8" -display_charset="UTF-8" ./PAGES-ASPIREES/"$compteur_tableau-$compteur".html > ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt;
						#---------------------------------------------------------
						iconv -t "$encodageURL" -f "UTF-8" < ./DUMP-TEXT/"$compteur_tableau-$compteur".html > ./DUMP-TEXT/"$compteur_tableau-$compteur".html
						# 2. compter les occurrences du mot choisi avec egrep et wc 
						compteurMotif=$(egrep -o -i $motif ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | wc -l);
						#---------------------------------------------------------
						# 3ème traitement, a) :extract des contextes.
						egrep -C 2 -i "$motif" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt > ./CONTEXTES/utf8_"$compteur_tableau-$compteur".txt;
						# 3 b) : avec le programme mini-egrep, nous creons un fichier html pour afficher les contextes. Deplacement du résultat au dossier CONTEXTES. 
						perl ./PROGRAMMES/minigrepmultilingue-v2.2-regexp/minigrepmultilingue.pl "UTF-8" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt ./PROGRAMMES/minigrepmultilingue-v2.2-regexp/motif-regexp.txt
						mv resultat-extraction.html ./CONTEXTES/"$compteur_tableau-$compteur".html
						#---------------------------------------------------------
						# 4ème traitement : Nous ferons un index ordonné de manière hierarchiques à partir du fichiers DUMP
						egrep -i -o "\w+" ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | sort | uniq -c  | sort -r -n -s -k 1,1 > ./DUMP-TEXT/index_"$compteur_tableau-$compteur".txt ;
						# 5ème traitement : Ensuite, on calcule les bigrammes pour connaître le contexte immédiat de notre motif.
						tr " " "\n" < ./DUMP-TEXT/utf8_"$compteur_tableau-$compteur".txt | tr -s "\n" | egrep -v "^$" > index1.txt ; tail -n +2 index1.txt  > index2.txt; paste index1.txt index2.txt | sort | uniq -c | sort -r -n -s -k 1,1 -r > ./DUMP-TEXT/bigramme_"$compteur_tableau-$compteur".txt ;
						#---------------------------------------------------------
						echo "<tr><td>$compteur</td>
						<td><span style=\"background-color:#00FFFF\">$codehttp</span></td>
						<td><span style=\"background-color:#00FFFF\">$encodageExtrait</span><br/><small>(Encode::Detect)</small></td>
						<td><a target=\"_blank\" href=\"$ligne\">$ligne</a></td>
						<td><a href=\"../PAGES-ASPIREES/$compteur_tableau-$compteur.html\">P.A n&deg;$compteur</a></td>
						<td><a href=\"../DUMP-TEXT/utf8_$compteur_tableau-$compteur.txt\">DUMP n&deg;$compteur</a></td><td>$compteurMotif</td>
						<td><a href=\"../CONTEXTES/utf8_$compteur_tableau-$compteur.txt\">contexte $compteur</a></td>
						<td><a href=\"../CONTEXTES/$compteur_tableau-$compteur.html\">contexte $compteur</a></td>
						<td><a href=\"../DUMP-TEXT/index_$compteur_tableau-$compteur.txt\">index $compteur</a></td>
						<td><a href=\"../DUMP-TEXT/bigramme_$compteur_tableau-$compteur.txt\">bigramme $compteur</a></td>
						<tr>" >> $tableaux;
					else
						# On remplit les colonnes en orange et on indique les donées qui ne sont pas encore extraites avec deux signes d'interrogation 
						echo "<tr><td>$compteur</td>
						<td><span style=\"background-color:#f97b5c\">$codehttp</span></td>
						<td><span style=\"background-color:#f97b5c\">$encodageURL</span></td>
						<td><a target=\"_blank\" href=\"$ligne\">$ligne</a></td>
						<td>-</td>
						<td>-</td>
						<td>-</td>
						<td>-</td>
						<td>-</td>
						<td>-</td>
						<td>-</td><tr>" >> $tableaux;
					fi
				fi
			fi
		else
			# Si le code http n'est pas 200, on remplit les tableaux avec un tiret court
			echo "PB HTTP----------------------------------"
			echo "<$compteur_tableau><$compteur><$ligne><$codeHttp>";
			echo "<tr><td>$compteur</td>
			<td>$codehttp</td>
			<td><a target=\"_blank\" href=\"$ligne\">$ligne</a></td>
			<td>-</td>
			<td>-</td>
			<td>-</td>
			<td>-</td>
			<td>-</td>
			<td>-</td>
			<td>-</td>
			<td>-</td><tr>" >> $tableaux;
		fi
		#---------------------------------------------------------------------
		compteur=$((compteur + 1)); 
		# On augmente le compter pour enumérer chaque ligne du tableau 
		done < $dossierURL/$fichier
		# On indique le chemin du fichier input, source élémentaire du démarrage de la boucle et de l'éxecution la commande curl 
		echo "</table>" >> $tableaux;
		echo "<p><hr color=\"blue\"></p>" >> $tableaux;
		compteur_tableau=$((compteur_tableau + 1)); # on augmente le compteur de tableau
	done
# on ferme le fichier html
echo "</body></html>" >> $tableaux;
